@@ -10,7 +10,7 @@ import publication
 from jsii.python import classproperty
 
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-waf", "1.0.0", __name__, "aws-waf@1.0.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-waf", "1.13.1", __name__, "aws-waf@1.13.1.jsii.tgz")
 class CfnByteMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-waf.CfnByteMatchSet"):
     """A CloudFormation ``AWS::WAF::ByteMatchSet``.
 
@@ -19,7 +19,7 @@ class CfnByteMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_ty
     cloudformationResource:
     :cloudformationResource:: AWS::WAF::ByteMatchSet
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, byte_match_tuples: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union["ByteMatchTupleProperty", aws_cdk.core.IResolvable]]]]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, byte_match_tuples: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]]]]]=None) -> None:
         """Create a new ``AWS::WAF::ByteMatchSet``.
 
         :param scope: - scope in which this resource is defined.
@@ -66,7 +66,7 @@ class CfnByteMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_ty
 
     @property
     @jsii.member(jsii_name="byteMatchTuples")
-    def byte_match_tuples(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union["ByteMatchTupleProperty", aws_cdk.core.IResolvable]]]]]:
+    def byte_match_tuples(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]]]]]:
         """``AWS::WAF::ByteMatchSet.ByteMatchTuples``.
 
         see
@@ -75,7 +75,7 @@ class CfnByteMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_ty
         return jsii.get(self, "byteMatchTuples")
 
     @byte_match_tuples.setter
-    def byte_match_tuples(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union["ByteMatchTupleProperty", aws_cdk.core.IResolvable]]]]]):
+    def byte_match_tuples(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ByteMatchTupleProperty"]]]]]):
         return jsii.set(self, "byteMatchTuples", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnByteMatchSet.ByteMatchTupleProperty", jsii_struct_bases=[], name_mapping={'field_to_match': 'fieldToMatch', 'positional_constraint': 'positionalConstraint', 'text_transformation': 'textTransformation', 'target_string': 'targetString', 'target_string_base64': 'targetStringBase64'})
@@ -200,7 +200,7 @@ class CfnByteMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_ty
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnByteMatchSetProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'byte_match_tuples': 'byteMatchTuples'})
 class CfnByteMatchSetProps():
-    def __init__(self, *, name: str, byte_match_tuples: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union["CfnByteMatchSet.ByteMatchTupleProperty", aws_cdk.core.IResolvable]]]]]=None):
+    def __init__(self, *, name: str, byte_match_tuples: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnByteMatchSet.ByteMatchTupleProperty"]]]]]=None):
         """Properties for defining a ``AWS::WAF::ByteMatchSet``.
 
         :param name: ``AWS::WAF::ByteMatchSet.Name``.
@@ -224,7 +224,7 @@ class CfnByteMatchSetProps():
         return self._values.get('name')
 
     @property
-    def byte_match_tuples(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union["CfnByteMatchSet.ByteMatchTupleProperty", aws_cdk.core.IResolvable]]]]]:
+    def byte_match_tuples(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnByteMatchSet.ByteMatchTupleProperty"]]]]]:
         """``AWS::WAF::ByteMatchSet.ByteMatchTuples``.
 
         see
@@ -1030,7 +1030,7 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
     cloudformationResource:
     :cloudformationResource:: AWS::WAF::WebACL
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, default_action: typing.Union[aws_cdk.core.IResolvable, "WafActionProperty"], metric_name: str, name: str, rules: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]]]]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, default_action: typing.Union["WafActionProperty", aws_cdk.core.IResolvable], metric_name: str, name: str, rules: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "ActivatedRuleProperty"]]]]]=None) -> None:
         """Create a new ``AWS::WAF::WebACL``.
 
         :param scope: - scope in which this resource is defined.
@@ -1065,7 +1065,7 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
 
     @property
     @jsii.member(jsii_name="defaultAction")
-    def default_action(self) -> typing.Union[aws_cdk.core.IResolvable, "WafActionProperty"]:
+    def default_action(self) -> typing.Union["WafActionProperty", aws_cdk.core.IResolvable]:
         """``AWS::WAF::WebACL.DefaultAction``.
 
         see
@@ -1074,7 +1074,7 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
         return jsii.get(self, "defaultAction")
 
     @default_action.setter
-    def default_action(self, value: typing.Union[aws_cdk.core.IResolvable, "WafActionProperty"]):
+    def default_action(self, value: typing.Union["WafActionProperty", aws_cdk.core.IResolvable]):
         return jsii.set(self, "defaultAction", value)
 
     @property
@@ -1121,7 +1121,7 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnWebACL.ActivatedRuleProperty", jsii_struct_bases=[], name_mapping={'priority': 'priority', 'rule_id': 'ruleId', 'action': 'action'})
     class ActivatedRuleProperty():
-        def __init__(self, *, priority: jsii.Number, rule_id: str, action: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWebACL.WafActionProperty"]]]=None):
+        def __init__(self, *, priority: jsii.Number, rule_id: str, action: typing.Optional[typing.Union[typing.Optional["CfnWebACL.WafActionProperty"], typing.Optional[aws_cdk.core.IResolvable]]]=None):
             """
             :param priority: ``CfnWebACL.ActivatedRuleProperty.Priority``.
             :param rule_id: ``CfnWebACL.ActivatedRuleProperty.RuleId``.
@@ -1155,7 +1155,7 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
             return self._values.get('rule_id')
 
         @property
-        def action(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWebACL.WafActionProperty"]]]:
+        def action(self) -> typing.Optional[typing.Union[typing.Optional["CfnWebACL.WafActionProperty"], typing.Optional[aws_cdk.core.IResolvable]]]:
             """``CfnWebACL.ActivatedRuleProperty.Action``.
 
             see
@@ -1208,7 +1208,7 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-waf.CfnWebACLProps", jsii_struct_bases=[], name_mapping={'default_action': 'defaultAction', 'metric_name': 'metricName', 'name': 'name', 'rules': 'rules'})
 class CfnWebACLProps():
-    def __init__(self, *, default_action: typing.Union[aws_cdk.core.IResolvable, "CfnWebACL.WafActionProperty"], metric_name: str, name: str, rules: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnWebACL.ActivatedRuleProperty"]]]]]=None):
+    def __init__(self, *, default_action: typing.Union["CfnWebACL.WafActionProperty", aws_cdk.core.IResolvable], metric_name: str, name: str, rules: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnWebACL.ActivatedRuleProperty"]]]]]=None):
         """Properties for defining a ``AWS::WAF::WebACL``.
 
         :param default_action: ``AWS::WAF::WebACL.DefaultAction``.
@@ -1227,7 +1227,7 @@ class CfnWebACLProps():
         if rules is not None: self._values["rules"] = rules
 
     @property
-    def default_action(self) -> typing.Union[aws_cdk.core.IResolvable, "CfnWebACL.WafActionProperty"]:
+    def default_action(self) -> typing.Union["CfnWebACL.WafActionProperty", aws_cdk.core.IResolvable]:
         """``AWS::WAF::WebACL.DefaultAction``.
 
         see
